package Form::Factory::Control::Role::PresetValue;
$Form::Factory::Control::Role::PresetValue::VERSION = '0.021';
use Moose::Role;

=head1 NAME

Form::Factory::Control::Role::PresetValue - controls with preset values

=head1 VERSION

version 0.021

=head1 DESCRIPTION

This role provides no methods or attributes. It flags the control as one with a preset value that does not change based upon user input. Buttons and hidden values are examples of presets.

=head1 AUTHOR

Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright 2009 Qubling Software LLC.

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
